@@ -2,8 +2,22 @@
 
 import click
 
-from fidesctl.cli.options import include_null_flag
-from fidesctl.cli.utils import with_analytics
+from fidesctl.cli.options import (
+    aws_access_key_id_option,
+    aws_region_option,
+    aws_secret_access_key_option,
+    connection_string_option,
+    credentials_id_option,
+    include_null_flag,
+    okta_org_url_option,
+    okta_token_option,
+)
+from fidesctl.cli.utils import (
+    handle_aws_credentials_options,
+    handle_database_credentials_options,
+    handle_okta_credentials_options,
+    with_analytics,
+)
 from fidesctl.core import dataset as _dataset
 from fidesctl.core import system as _system
 
@@ -26,47 +40,35 @@ def generate_dataset(ctx: click.Context) -> None:
 
 @generate_dataset.command(name="db")
 @click.pass_context
-@click.argument("connection_string", type=str)
 @click.argument("output_filename", type=str)
+@credentials_id_option
+@connection_string_option
 @include_null_flag
 @with_analytics
 def generate_dataset_db(
-    ctx: click.Context, connection_string: str, output_filename: str, include_null: bool
+    ctx: click.Context,
+    output_filename: str,
+    connection_string: str,
+    credentials_id: str,
+    include_null: bool,
 ) -> None:
     """
     Connect to a database directly via a SQLAlchemy-style connection string and
     generate a dataset manifest file that consists of every schema/table/field.
+    Connection string can be supplied as an option or a credentials reference
+    to fidesctl config.
 
     This is a one-time operation that does not track the state of the database.
     It will need to be run again if the database schema changes.
     """
-    _dataset.generate_dataset_db(
+    actual_connection_string = handle_database_credentials_options(
+        fides_config=ctx.obj["CONFIG"],
         connection_string=connection_string,
-        file_name=output_filename,
-        include_null=include_null,
+        credentials_id=credentials_id,
     )
 
-
-@generate_dataset.command(name="okta")
-@click.pass_context
-@click.argument("org_url", type=str)
-@click.argument("output_filename", type=str)
-@include_null_flag
-@with_analytics
-def generate_dataset_okta(
-    ctx: click.Context, org_url: str, output_filename: str, include_null: bool
-) -> None:
-    """
-    Generates datasets for your Okta applications. Connect to an Okta admin
-    account by providing an organization url. Auth token can be supplied by
-    setting the environment variable OKTA_CLIENT_TOKEN.
-
-    This is a one-time operation that does not track the state of the okta resources.
-    It will need to be run again if the tracked resources change.
-    """
-
-    _dataset.generate_dataset_okta(
-        org_url=org_url,
+    _dataset.generate_dataset_db(
+        connection_string=actual_connection_string,
         file_name=output_filename,
         include_null=include_null,
     )
@@ -80,9 +82,52 @@ def generate_system(ctx: click.Context) -> None:
     """
 
 
+@generate_system.command(name="okta")
+@click.pass_context
+@click.argument("output_filename", type=str)
+@credentials_id_option
+@okta_org_url_option
+@okta_token_option
+@include_null_flag
+@with_analytics
+def generate_system_okta(
+    ctx: click.Context,
+    output_filename: str,
+    credentials_id: str,
+    token: str,
+    org_url: str,
+    include_null: bool,
+) -> None:
+    """
+    Generates systems for your Okta applications. Connect to an Okta admin
+    account by providing an organization url and auth token or a credentials
+    reference to fidesctl config. Auth token and organization url can also
+    be supplied by setting environment variables as defined by the okta python sdk.
+
+    This is a one-time operation that does not track the state of the okta resources.
+    It will need to be run again if the tracked resources change.
+    """
+    okta_config = handle_okta_credentials_options(
+        fides_config=ctx.obj["CONFIG"],
+        token=token,
+        org_url=org_url,
+        credentials_id=credentials_id,
+    )
+
+    _system.generate_system_okta(
+        okta_config=okta_config,
+        file_name=output_filename,
+        include_null=include_null,
+    )
+
+
 @generate_system.command(name="aws")
 @click.pass_context
 @click.argument("output_filename", type=str)
+@credentials_id_option
+@aws_access_key_id_option
+@aws_secret_access_key_option
+@aws_region_option
 @include_null_flag
 @click.option("-o", "--organization", type=str, default="default_organization")
 @with_analytics
@@ -91,21 +136,35 @@ def generate_system_aws(
     output_filename: str,
     include_null: bool,
     organization: str,
+    credentials_id: str,
+    access_key_id: str,
+    secret_access_key: str,
+    region: str,
 ) -> None:
     """
-    Connect to an aws account by leveraging a boto3 environment variable
-    configuration and generate a system manifest file that consists of every
-    tracked resource. Tracked resources: [Redshift, RDS]
+    Connect to an aws account and generate a system manifest file that consists of every
+    tracked resource.
+    Credentials can be supplied as options, a credentials
+    reference to fidesctl config, or boto3 environment configuration.
+    Tracked resources: [Redshift, RDS]
 
     This is a one-time operation that does not track the state of the aws resources.
     It will need to be run again if the tracked resources change.
     """
-
     config = ctx.obj["CONFIG"]
+    aws_config = handle_aws_credentials_options(
+        fides_config=config,
+        access_key_id=access_key_id,
+        secret_access_key=secret_access_key,
+        region=region,
+        credentials_id=credentials_id,
+    )
+
     _system.generate_system_aws(
         file_name=output_filename,
         include_null=include_null,
         organization_key=organization,
+        aws_config=aws_config,
         url=config.cli.server_url,
         headers=config.user.request_headers,
     )
