@@ -3,6 +3,8 @@ This module is responsible for combining all of the different
 config sections into a single config.
 """
 
+from typing import Dict
+
 import toml
 from pydantic import BaseModel
 
@@ -11,6 +13,7 @@ from fidesctl.core.utils import echo_red
 
 from .api_settings import APISettings
 from .cli_settings import CLISettings
+from .credentials_settings import merge_credentials_environment
 from .user_settings import UserSettings
 
 
@@ -20,6 +23,7 @@ class FidesctlConfig(BaseModel):
     api: APISettings = APISettings()
     cli: CLISettings = CLISettings()
     user: UserSettings = UserSettings()
+    credentials: Dict[str, Dict] = dict()
 
 
 def get_config(config_path: str = "") -> FidesctlConfig:
@@ -34,6 +38,14 @@ def get_config(config_path: str = "") -> FidesctlConfig:
     try:
         file_location = get_config_path(config_path)
         settings = toml.load(file_location)
+
+        # credentials specific logic for populating environment variable configs.
+        # this is done to allow overrides without hard typed pydantic models
+        config_environment_dict = settings.get("credentials", dict())
+        settings["credentials"] = merge_credentials_environment(
+            credentials_dict=config_environment_dict
+        )
+
         fidesctl_config = FidesctlConfig.parse_obj(settings)
         return fidesctl_config
     except FileNotFoundError:
