@@ -2,13 +2,6 @@
 import uuid
 from typing import Callable, Dict, List, Optional, Set, cast
 
-from pydantic import AnyHttpUrl
-
-from fidesctl.cli.utils import handle_cli_response, pretty_echo
-from fidesctl.core import api
-from fidesctl.core.api_helpers import get_server_resource, get_server_resources
-from fidesctl.core.parse import parse
-from fidesctl.core.utils import echo_green, echo_red, get_all_level_fields
 from fideslang.default_taxonomy import DEFAULT_TAXONOMY
 from fideslang.models import (
     Dataset,
@@ -23,12 +16,16 @@ from fideslang.models import (
     Violation,
     ViolationAttributes,
 )
-from fideslang.relationships import (
-    get_referenced_missing_keys,
-    hydrate_missing_resources,
-)
+from fideslang.relationships import get_referenced_missing_keys
 from fideslang.utils import get_resource_by_fides_key
 from fideslang.validation import FidesKey
+from pydantic import AnyHttpUrl
+
+from fidesctl.cli.utils import handle_cli_response, pretty_echo
+from fidesctl.core import api
+from fidesctl.core.api_helpers import get_server_resource, get_server_resources
+from fidesctl.core.parse import parse
+from fidesctl.core.utils import echo_green, echo_red, get_all_level_fields
 
 
 def get_evaluation_policies(
@@ -438,6 +435,31 @@ def execute_evaluation(taxonomy: Taxonomy) -> Evaluation:
     return evaluation
 
 
+def hydrate_missing_resources(
+    url: AnyHttpUrl,
+    headers: Dict[str, str],
+    missing_resource_keys: List[FidesKey],
+    dehydrated_taxonomy: Taxonomy,
+) -> Taxonomy:
+    """
+    Query the server for all of the missing resource keys and
+    hydrate a copy of the dehydrated taxonomy with them.
+    """
+
+    for resource_name in dehydrated_taxonomy.__fields__:
+        server_resources = get_server_resources(
+            url=url,
+            resource_type=resource_name,
+            headers=headers,
+            existing_keys=missing_resource_keys,
+        )
+        dehydrated_taxonomy.__setattr__(
+            resource_name,
+            getattr(dehydrated_taxonomy, resource_name) + server_resources,
+        )
+    return dehydrated_taxonomy
+
+
 def populate_referenced_keys(
     taxonomy: Taxonomy,
     url: AnyHttpUrl,
@@ -469,6 +491,30 @@ def populate_referenced_keys(
     return taxonomy
 
 
+def merge_taxonomies(
+    primary_taxonomy: Taxonomy, secondary_taxonomy: Taxonomy
+) -> Taxonomy:
+    """
+    Merges the secondary_taxonomy into the primary_taxonomy while
+    preserving all of the existing keys within the primary_taxonomy.
+    """
+    for resource_name in primary_taxonomy.__fields__:
+        # Get the unique set of keys we want to include in the merged taxonomy
+        primary_keys = [
+            resource.fides_key for resource in getattr(primary_taxonomy, resource_name)
+        ]
+        secondary_resources = [
+            resource
+            for resource in getattr(secondary_taxonomy, resource_name)
+            if resource.fides_key not in primary_keys
+        ]
+        # Create a list of all of the resources to go in the merged taxonomy
+        resource_list = getattr(primary_taxonomy, resource_name) + secondary_resources
+        setattr(primary_taxonomy, resource_name, resource_list)
+
+    return primary_taxonomy
+
+
 def evaluate(
     url: AnyHttpUrl,
     manifests_dir: str,
@@ -488,12 +534,7 @@ def evaluate(
 
     # Merge the User-defined taxonomy & Default Taxonomy
     user_taxonomy = parse(manifests_dir)
-    taxonomy = Taxonomy.parse_obj(
-        {
-            **DEFAULT_TAXONOMY.dict(exclude_unset=True),
-            **user_taxonomy.dict(exclude_unset=True),
-        }
-    )
+    taxonomy = merge_taxonomies(user_taxonomy, DEFAULT_TAXONOMY)
 
     # Determine which Policies will be evaluated
     policies = taxonomy.policy
